@@ -20,9 +20,18 @@
  * Author: Daniel P. Berrange <berrange@redhat.com>
  */
 
-#ifndef VIEWER_H
-#define VIEWER_H
+#ifndef VIRT_VIEWER_H
+#define VIRT_VIEWER_H
 
-extern int viewer_start (const char *uri, const char *name, int direct, int waitvnc, int set_verbose, GtkWidget *(*get_toplevel)(void *), void *data, int with_menubar);
+#include "util.h"
 
-#endif /* VIEWER_H */
+extern int viewer_start (const char *uri,
+			 const char *name,
+			 gboolean direct,
+			 gboolean waitvm,
+			 gboolean reconnect,
+			 gboolean verbose,
+			 gboolean debug,
+			 GtkWidget *container);
+
+#endif /* VIRT_VIEWER_H */
